@@ -7,7 +7,7 @@ from urllib.parse import urlparse
 from .image import url2mime
 
 
-__version__ = '0.7.6'
+__version__ = '0.7.7'
 
 renderers: Dict = {}
 
@@ -154,11 +154,7 @@ class Paragraph(BaseContainer):
     wrap_tag: str = "p"
 
     def is_renderable(self, node):
-        text = ''
-        content = node.get('content', [])
-        if content:
-            text = content[0].get('text', '')
-        return bool(text)
+        return bool(node.get('content'))
 
 
 class BlockQuote(BaseContainer):
